@@ -1,4 +1,6 @@
 from . import _tsp_c
 from .tsp_c import solve_greedy
 from .tsp_c import solve_SA
-from .tsp_c import set_param_SA
\ No newline at end of file
+from .tsp_c import set_param_SA
+from .tsp_c import solve_PSO
+from .tsp_c import solve_ACO
\ No newline at end of file
